# Generated by Django 4.1.7 on 2023-04-03 17:25

from django.db import migrations, models
import edc_model.validators.date


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0017_alter_bloodresultsfbc_results_abnormal_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalhivinitialreview",
            name="vl_date",
        ),
        migrations.RemoveField(
            model_name="hivinitialreview",
            name="vl_date",
        ),
        migrations.AddField(
            model_name="historicalhivinitialreview",
            name="drawn_date",
            field=models.DateField(
                blank=True,
                help_text="If exact date not known, please estimate",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date specimen drawn",
            ),
        ),
        migrations.AddField(
            model_name="hivinitialreview",
            name="drawn_date",
            field=models.DateField(
                blank=True,
                help_text="If exact date not known, please estimate",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date specimen drawn",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="dmreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="arv_initiation_actual_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating above.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started antiretroviral therapy (ART)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="vl_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", "Not applicable"),
                    ("=", "="),
                    (">", ">"),
                    ("<", "<"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalviralloadresult",
            name="vl_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", "Not applicable"),
                    ("=", "="),
                    (">", ">"),
                    ("<", "<"),
                    ("N/A", "Not applicable"),
                ],
                default="=",
                max_length=10,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalvitals",
            name="comments",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="arv_initiation_actual_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating above.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started antiretroviral therapy (ART)",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="vl_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", "Not applicable"),
                    ("=", "="),
                    (">", ">"),
                    ("<", "<"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="viralloadresult",
            name="vl_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", "Not applicable"),
                    ("=", "="),
                    (">", ">"),
                    ("<", "<"),
                    ("N/A", "Not applicable"),
                ],
                default="=",
                max_length=10,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="vitals",
            name="comments",
            field=models.TextField(blank=True, null=True),
        ),
    ]
