# Generated by Django 4.2.7 on 2023-12-04 14:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_lists", "0008_medicationshortagereasons"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="arvdrugs",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Arv Drugs",
                "verbose_name_plural": "Arv Drugs",
            },
        ),
        migrations.AlterModelOptions(
            name="arvregimens",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "ARV Regimens",
                "verbose_name_plural": "ARV Regimens",
            },
        ),
        migrations.AlterModelOptions(
            name="clinicalwithdrawalreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Clinical Withdrawal Reasons",
                "verbose_name_plural": "Clinical Withdrawal Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="clinicservices",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Clinic Services",
                "verbose_name_plural": "Clinic Services",
            },
        ),
        migrations.AlterModelOptions(
            name="conditions",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Conditions",
                "verbose_name_plural": "Conditions",
            },
        ),
        migrations.AlterModelOptions(
            name="consentrefusalreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Consent Refusal Reasons",
                "verbose_name_plural": "Consent Refusal Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="dmmanagement",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Diabetes Management",
                "verbose_name_plural": "Diabetes Management",
            },
        ),
        migrations.AlterModelOptions(
            name="dmtreatments",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Diabetes Treatments",
                "verbose_name_plural": "Diabetes Treatments",
            },
        ),
        migrations.AlterModelOptions(
            name="drugdispensaries",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Drug Dispensaries",
                "verbose_name_plural": "Drug Dispensaries",
            },
        ),
        migrations.AlterModelOptions(
            name="drugdispensers",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Drug Dispensers",
                "verbose_name_plural": "Drug Dispensers",
            },
        ),
        migrations.AlterModelOptions(
            name="drugpaysources",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Drug Payment Sources",
                "verbose_name_plural": "Drug Payment Sources",
            },
        ),
        migrations.AlterModelOptions(
            name="healthadvisors",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Advisors",
                "verbose_name_plural": "Health Advisors",
            },
        ),
        migrations.AlterModelOptions(
            name="healthfacilitytypes",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Facility Type",
                "verbose_name_plural": "Health Facility Types",
            },
        ),
        migrations.AlterModelOptions(
            name="healthinterventiontypes",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Intervention Types",
                "verbose_name_plural": "Health Intervention Types",
            },
        ),
        migrations.AlterModelOptions(
            name="healthservices",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Services",
                "verbose_name_plural": "Health Services",
            },
        ),
        migrations.AlterModelOptions(
            name="healthtalkconditions",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Talk Conditions",
                "verbose_name_plural": "Health Talk Conditions",
            },
        ),
        migrations.AlterModelOptions(
            name="healthtalktypes",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Talk Type",
                "verbose_name_plural": "Health Talk Types",
            },
        ),
        migrations.AlterModelOptions(
            name="htnmanagement",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "HTN Management",
                "verbose_name_plural": "HTN Management",
            },
        ),
        migrations.AlterModelOptions(
            name="htntreatments",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Hypertension Treatments",
                "verbose_name_plural": "Hypertension Treatments",
            },
        ),
        migrations.AlterModelOptions(
            name="laboratorytests",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Laboratory Tests",
                "verbose_name_plural": "Laboratory Tests",
            },
        ),
        migrations.AlterModelOptions(
            name="locationtypes",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Community-care location type",
                "verbose_name_plural": "Community-care location types",
            },
        ),
        migrations.AlterModelOptions(
            name="medicationshortagereasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Medication shortage reasons",
                "verbose_name_plural": "Medication shortage reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="nonadherencereasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "NonAdherence Reasons",
                "verbose_name_plural": "NonAdherence Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="offstudyreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Offstudy Reasons",
                "verbose_name_plural": "Offstudy Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="refillconditions",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Refill Conditions",
                "verbose_name_plural": "Refill Conditions",
            },
        ),
        migrations.AlterModelOptions(
            name="rxmodificationreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Treatment Modification Reasons",
                "verbose_name_plural": "Treatment Modification Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="rxmodifications",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Treatment Modifications",
                "verbose_name_plural": "Treatment Modifications",
            },
        ),
        migrations.AlterModelOptions(
            name="screeningrefusalreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Screening Refusal Reasons",
                "verbose_name_plural": "Screening Refusal Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectvisitmissedreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Subject Missed Visit Reasons",
                "verbose_name_plural": "Subject Missed Visit Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="toxicitywithdrawalreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Toxicity Withdrawal Reasons",
                "verbose_name_plural": "Toxicity Withdrawal Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="transferreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Transfer Reasons",
                "verbose_name_plural": "Transfer Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="transportchoices",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Transport Choices",
                "verbose_name_plural": "Transport Choices",
            },
        ),
        migrations.AlterModelOptions(
            name="visitreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Visit Reasons",
                "verbose_name_plural": "Visit Reasons",
            },
        ),
        migrations.RemoveIndex(
            model_name="arvdrugs",
            name="intecomm_li_id_82a046_idx",
        ),
        migrations.RemoveIndex(
            model_name="arvregimens",
            name="intecomm_li_id_963095_idx",
        ),
        migrations.RemoveIndex(
            model_name="clinicalwithdrawalreasons",
            name="intecomm_li_id_33f6f1_idx",
        ),
        migrations.RemoveIndex(
            model_name="clinicservices",
            name="intecomm_li_id_97c7c2_idx",
        ),
        migrations.RemoveIndex(
            model_name="conditions",
            name="intecomm_li_id_a3d457_idx",
        ),
        migrations.RemoveIndex(
            model_name="consentrefusalreasons",
            name="intecomm_li_id_3f4631_idx",
        ),
        migrations.RemoveIndex(
            model_name="dmmanagement",
            name="intecomm_li_id_b4d41f_idx",
        ),
        migrations.RemoveIndex(
            model_name="dmtreatments",
            name="intecomm_li_id_aa0a3b_idx",
        ),
        migrations.RemoveIndex(
            model_name="drugdispensaries",
            name="intecomm_li_id_ffb6be_idx",
        ),
        migrations.RemoveIndex(
            model_name="drugdispensers",
            name="intecomm_li_id_cc5dec_idx",
        ),
        migrations.RemoveIndex(
            model_name="drugpaysources",
            name="intecomm_li_id_27e420_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthadvisors",
            name="intecomm_li_id_ffdb67_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthfacilitytypes",
            name="intecomm_li_id_727813_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthinterventiontypes",
            name="intecomm_li_id_9b4020_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthservices",
            name="intecomm_li_id_1604f4_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthtalkconditions",
            name="intecomm_li_id_21baf0_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthtalktypes",
            name="intecomm_li_id_5f9413_idx",
        ),
        migrations.RemoveIndex(
            model_name="htnmanagement",
            name="intecomm_li_id_91f6e0_idx",
        ),
        migrations.RemoveIndex(
            model_name="htntreatments",
            name="intecomm_li_id_ce0438_idx",
        ),
        migrations.RemoveIndex(
            model_name="laboratorytests",
            name="intecomm_li_id_b0664c_idx",
        ),
        migrations.RemoveIndex(
            model_name="locationtypes",
            name="intecomm_li_id_8c336e_idx",
        ),
        migrations.RemoveIndex(
            model_name="medicationshortagereasons",
            name="intecomm_li_id_50cc4d_idx",
        ),
        migrations.RemoveIndex(
            model_name="nonadherencereasons",
            name="intecomm_li_id_31cb50_idx",
        ),
        migrations.RemoveIndex(
            model_name="offstudyreasons",
            name="intecomm_li_id_c1b6d2_idx",
        ),
        migrations.RemoveIndex(
            model_name="refillconditions",
            name="intecomm_li_id_17855a_idx",
        ),
        migrations.RemoveIndex(
            model_name="rxmodificationreasons",
            name="intecomm_li_id_c4f7bb_idx",
        ),
        migrations.RemoveIndex(
            model_name="rxmodifications",
            name="intecomm_li_id_4fd810_idx",
        ),
        migrations.RemoveIndex(
            model_name="screeningrefusalreasons",
            name="intecomm_li_id_3c9136_idx",
        ),
        migrations.RemoveIndex(
            model_name="subjectvisitmissedreasons",
            name="intecomm_li_id_6fb3a6_idx",
        ),
        migrations.RemoveIndex(
            model_name="toxicitywithdrawalreasons",
            name="intecomm_li_id_710a9d_idx",
        ),
        migrations.RemoveIndex(
            model_name="transferreasons",
            name="intecomm_li_id_58872e_idx",
        ),
        migrations.RemoveIndex(
            model_name="transportchoices",
            name="intecomm_li_id_8a0a27_idx",
        ),
        migrations.RemoveIndex(
            model_name="visitreasons",
            name="intecomm_li_id_1dbf9b_idx",
        ),
        migrations.AlterField(
            model_name="arvdrugs",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="arvdrugs",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="arvdrugs",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="arvregimens",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="arvregimens",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="arvregimens",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalwithdrawalreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalwithdrawalreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalwithdrawalreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="clinicservices",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="clinicservices",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="clinicservices",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="conditions",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="conditions",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="conditions",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="consentrefusalreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="consentrefusalreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="consentrefusalreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="dmmanagement",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="dmmanagement",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="dmmanagement",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="dmtreatments",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="dmtreatments",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="dmtreatments",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="drugdispensaries",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="drugdispensaries",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="drugdispensaries",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="drugdispensers",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="drugdispensers",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="drugdispensers",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="drugpaysources",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="drugpaysources",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="drugpaysources",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="healthadvisors",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="healthadvisors",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="healthadvisors",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="healthfacilitytypes",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="healthfacilitytypes",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="healthfacilitytypes",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="healthinterventiontypes",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="healthinterventiontypes",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="healthinterventiontypes",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="healthservices",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="healthservices",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="healthservices",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="healthtalkconditions",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="healthtalkconditions",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="healthtalkconditions",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="healthtalktypes",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="healthtalktypes",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="healthtalktypes",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="htnmanagement",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="htnmanagement",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="htnmanagement",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="htntreatments",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="htntreatments",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="htntreatments",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="laboratorytests",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="laboratorytests",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="laboratorytests",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="locationtypes",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="locationtypes",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="locationtypes",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="medicationshortagereasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="medicationshortagereasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="medicationshortagereasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="offstudyreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="offstudyreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="offstudyreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="refillconditions",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="refillconditions",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="refillconditions",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="rxmodificationreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="rxmodificationreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="rxmodificationreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="rxmodifications",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="rxmodifications",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="rxmodifications",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="screeningrefusalreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="screeningrefusalreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="screeningrefusalreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="toxicitywithdrawalreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="toxicitywithdrawalreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="toxicitywithdrawalreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="transferreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="transferreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="transferreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="transportchoices",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="transportchoices",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="transportchoices",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="visitreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="visitreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="visitreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AddIndex(
            model_name="arvdrugs",
            index=models.Index(fields=["name"], name="intecomm_li_name_b55bdc_idx"),
        ),
        migrations.AddIndex(
            model_name="arvdrugs",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_6fd0a7_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="arvregimens",
            index=models.Index(fields=["name"], name="intecomm_li_name_dd4128_idx"),
        ),
        migrations.AddIndex(
            model_name="arvregimens",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_109d17_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="clinicalwithdrawalreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_bfca7f_idx"),
        ),
        migrations.AddIndex(
            model_name="clinicalwithdrawalreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_23f821_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="clinicservices",
            index=models.Index(fields=["name"], name="intecomm_li_name_deec16_idx"),
        ),
        migrations.AddIndex(
            model_name="clinicservices",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_ed922c_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="conditions",
            index=models.Index(fields=["name"], name="intecomm_li_name_b9ae61_idx"),
        ),
        migrations.AddIndex(
            model_name="conditions",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_7a1347_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="consentrefusalreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_04461e_idx"),
        ),
        migrations.AddIndex(
            model_name="consentrefusalreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_c72ae6_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="dmmanagement",
            index=models.Index(fields=["name"], name="intecomm_li_name_edefb8_idx"),
        ),
        migrations.AddIndex(
            model_name="dmmanagement",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_a3448c_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="dmtreatments",
            index=models.Index(fields=["name"], name="intecomm_li_name_596944_idx"),
        ),
        migrations.AddIndex(
            model_name="dmtreatments",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_5e34e8_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="drugdispensaries",
            index=models.Index(fields=["name"], name="intecomm_li_name_2312cd_idx"),
        ),
        migrations.AddIndex(
            model_name="drugdispensaries",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_41855f_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="drugdispensers",
            index=models.Index(fields=["name"], name="intecomm_li_name_4d9885_idx"),
        ),
        migrations.AddIndex(
            model_name="drugdispensers",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_31917d_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="drugpaysources",
            index=models.Index(fields=["name"], name="intecomm_li_name_b764fd_idx"),
        ),
        migrations.AddIndex(
            model_name="drugpaysources",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_27e119_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthadvisors",
            index=models.Index(fields=["name"], name="intecomm_li_name_dd5fb2_idx"),
        ),
        migrations.AddIndex(
            model_name="healthadvisors",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_d0813b_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthfacilitytypes",
            index=models.Index(fields=["name"], name="intecomm_li_name_af9934_idx"),
        ),
        migrations.AddIndex(
            model_name="healthfacilitytypes",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_d3d5f9_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthinterventiontypes",
            index=models.Index(fields=["name"], name="intecomm_li_name_5a8bd1_idx"),
        ),
        migrations.AddIndex(
            model_name="healthinterventiontypes",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_7bf3e3_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthservices",
            index=models.Index(fields=["name"], name="intecomm_li_name_b9dd17_idx"),
        ),
        migrations.AddIndex(
            model_name="healthservices",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_b2eff6_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthtalkconditions",
            index=models.Index(fields=["name"], name="intecomm_li_name_9d805e_idx"),
        ),
        migrations.AddIndex(
            model_name="healthtalkconditions",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_a5c489_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthtalktypes",
            index=models.Index(fields=["name"], name="intecomm_li_name_dae47f_idx"),
        ),
        migrations.AddIndex(
            model_name="healthtalktypes",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_c68c32_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="htnmanagement",
            index=models.Index(fields=["name"], name="intecomm_li_name_17a894_idx"),
        ),
        migrations.AddIndex(
            model_name="htnmanagement",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_975a4f_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="htntreatments",
            index=models.Index(fields=["name"], name="intecomm_li_name_ebbf62_idx"),
        ),
        migrations.AddIndex(
            model_name="htntreatments",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_66b578_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="laboratorytests",
            index=models.Index(fields=["name"], name="intecomm_li_name_3dad94_idx"),
        ),
        migrations.AddIndex(
            model_name="laboratorytests",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_64caa0_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="locationtypes",
            index=models.Index(fields=["name"], name="intecomm_li_name_f97934_idx"),
        ),
        migrations.AddIndex(
            model_name="locationtypes",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_a20bbc_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="medicationshortagereasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_ad571f_idx"),
        ),
        migrations.AddIndex(
            model_name="medicationshortagereasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_99567a_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="nonadherencereasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_a7a6a5_idx"),
        ),
        migrations.AddIndex(
            model_name="nonadherencereasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_6edd6e_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offstudyreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_aabb4d_idx"),
        ),
        migrations.AddIndex(
            model_name="offstudyreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_676026_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="refillconditions",
            index=models.Index(fields=["name"], name="intecomm_li_name_085d7f_idx"),
        ),
        migrations.AddIndex(
            model_name="refillconditions",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_041362_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="rxmodificationreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_c1233d_idx"),
        ),
        migrations.AddIndex(
            model_name="rxmodificationreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_f59fe7_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="rxmodifications",
            index=models.Index(fields=["name"], name="intecomm_li_name_3f4bd2_idx"),
        ),
        migrations.AddIndex(
            model_name="rxmodifications",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_8ee785_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="screeningrefusalreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_1da54a_idx"),
        ),
        migrations.AddIndex(
            model_name="screeningrefusalreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_a4540f_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjectvisitmissedreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_12d94d_idx"),
        ),
        migrations.AddIndex(
            model_name="subjectvisitmissedreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_11b10d_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="toxicitywithdrawalreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_30f17d_idx"),
        ),
        migrations.AddIndex(
            model_name="toxicitywithdrawalreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_54eafe_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="transferreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_eb67c1_idx"),
        ),
        migrations.AddIndex(
            model_name="transferreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_852f8a_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="transportchoices",
            index=models.Index(fields=["name"], name="intecomm_li_name_bea030_idx"),
        ),
        migrations.AddIndex(
            model_name="transportchoices",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_726107_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="visitreasons",
            index=models.Index(fields=["name"], name="intecomm_li_name_59f9c6_idx"),
        ),
        migrations.AddIndex(
            model_name="visitreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="intecomm_li_display_0b9635_idx",
            ),
        ),
    ]
