# Generated by Django 4.2.7 on 2023-11-29 20:50

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0127_alter_historicalsubjectvisitmissed_appt_date_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalsubjectvisit",
            name="clinic_services_other",
        ),
        migrations.RemoveField(
            model_name="subjectvisit",
            name="clinic_services",
        ),
        migrations.RemoveField(
            model_name="subjectvisit",
            name="clinic_services_other",
        ),
        migrations.RemoveField(
            model_name="subjectvisit",
            name="health_services",
        ),
    ]
