# Generated by Django 4.2.3 on 2023-08-07 22:12

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0090_alter_healtheconomicshouseholdhead_hoh_age_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="healtheconomicsassets",
            name="solar_panels",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Solar panels",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicsassets",
            name="solar_panels",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Solar panels",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="bicycle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Bicycle",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="car",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Car",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="computer",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Computer",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="dala_dala",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Dala Dala",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="eaves",
            field=models.CharField(
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="Are the eaves open, partially or fully closed?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="fridge",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Fridge",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="generator",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Generator",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="iron",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Flat iron",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="large_livestock",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="lighting_source",
            field=models.CharField(
                choices=[
                    ("1", "Electricity"),
                    ("2", "Paraffin, kerosene or gas lantern "),
                    ("3", "Firewood"),
                    ("4", "Candle"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="What is the main source of lighting?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="mobile_phone",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Mobile phone",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="motorboat",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Boat with a motor",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="motorcycle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Motorcycle/scooter (PikiPiki/Boda Boda)",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="radio",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Radio",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="shop",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="A business or shop",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="small_animals",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Small animals (goats, sheep, chickens or other poultry, etc)",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="telephone",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Non-mobile telephone",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="television",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Television",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="window_screen_type",
            field=models.CharField(
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="Type of screening on external windows",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="window_screens",
            field=models.CharField(
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="What is the main screening material of external windows?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="bicycle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Bicycle",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="car",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Car",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="computer",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Computer",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="dala_dala",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Dala Dala",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="eaves",
            field=models.CharField(
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="Are the eaves open, partially or fully closed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="fridge",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Fridge",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="generator",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Generator",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="iron",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Flat iron",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="large_livestock",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Large Livestock (e.g. cows, bulls, other cattle, horses, donkeys)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="lighting_source",
            field=models.CharField(
                choices=[
                    ("1", "Electricity"),
                    ("2", "Paraffin, kerosene or gas lantern "),
                    ("3", "Firewood"),
                    ("4", "Candle"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="What is the main source of lighting?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="mobile_phone",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Mobile phone",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="motorboat",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Boat with a motor",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="motorcycle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Motorcycle/scooter (PikiPiki/Boda Boda)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="radio",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Radio",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="shop",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="A business or shop",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="small_animals",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Small animals (goats, sheep, chickens or other poultry, etc)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="telephone",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Non-mobile telephone",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="television",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Television",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="window_screen_type",
            field=models.CharField(
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="Type of screening on external windows",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="window_screens",
            field=models.CharField(
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="What is the main screening material of external windows?",
            ),
        ),
    ]
