# Generated by Django 4.1.7 on 2023-04-06 19:31

from django.db import migrations, models
import edc_model.validators.date


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0026_rename_dminitialreview_med_start_date_estimated_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="dminitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started None?",
            ),
        ),
        migrations.AddField(
            model_name="dminitialreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating above.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started None",
            ),
        ),
        migrations.AddField(
            model_name="historicaldminitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started None?",
            ),
        ),
        migrations.AddField(
            model_name="historicaldminitialreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started None",
            ),
        ),
        migrations.AddField(
            model_name="historicaldminitialreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating above.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started None",
            ),
        ),
        migrations.AddField(
            model_name="historicalhtninitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started medicines for hypertension?",
            ),
        ),
        migrations.AddField(
            model_name="historicalhtninitialreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was medicines for hypertension start date estimated?",
            ),
        ),
        migrations.AddField(
            model_name="htninitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started medicines for hypertension?",
            ),
        ),
        migrations.AddField(
            model_name="htninitialreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was medicines for hypertension start date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="dx_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `dxdx_ago`",
                null=True,
                verbose_name="Estimated diagnosis date",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="dx_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was the diagnosis date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started None",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was None start date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="singleton_field",
            field=models.CharField(
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                unique=True,
                verbose_name="subject identifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="dx_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `dxdx_ago`",
                null=True,
                verbose_name="Estimated diagnosis date",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="dx_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was the diagnosis date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was None start date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="singleton_field",
            field=models.CharField(
                db_index=True,
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                verbose_name="subject identifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="dx_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `dxdx_ago`",
                null=True,
                verbose_name="Estimated diagnosis date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="dx_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was the diagnosis date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started antiretroviral therapy (ART)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was antiretroviral therapy (ART) start date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="singleton_field",
            field=models.CharField(
                db_index=True,
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                verbose_name="subject identifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="dx_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `dxdx_ago`",
                null=True,
                verbose_name="Estimated diagnosis date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="dx_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was the diagnosis date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started medicines for hypertension",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating above.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started medicines for hypertension",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="singleton_field",
            field=models.CharField(
                db_index=True,
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                verbose_name="subject identifier",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="dx_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `dxdx_ago`",
                null=True,
                verbose_name="Estimated diagnosis date",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="dx_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was the diagnosis date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started antiretroviral therapy (ART)",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was antiretroviral therapy (ART) start date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="singleton_field",
            field=models.CharField(
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                unique=True,
                verbose_name="subject identifier",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="dx_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `dxdx_ago`",
                null=True,
                verbose_name="Estimated diagnosis date",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="dx_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was the diagnosis date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started medicines for hypertension",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating above.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started medicines for hypertension",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="singleton_field",
            field=models.CharField(
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                unique=True,
                verbose_name="subject identifier",
            ),
        ),
    ]
