# Generated by Django 4.1.7 on 2023-04-21 20:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0035_alter_drugrefilldm_return_in_days_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dminitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started medicines for diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started medicines for diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started antiretroviral therapy (ART)?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started medicines for hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started antiretroviral therapy (ART)?",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started medicines for hypertension?",
            ),
        ),
    ]
