# Generated by Django 4.2.1 on 2023-05-23 23:00

from django.db import migrations
import edc_model_fields.fields.other_charfield


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0042_alter_bloodresultsins_fasting_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="healtheconomicshouseholdhead",
            name="relationship_to_hoh_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER relationship, specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="relationship_to_hoh_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER relationship, specify ...",
            ),
        ),
    ]
