# Generated by Django 4.2.3 on 2023-07-25 18:31

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        # ("intecomm_facility", "0002_alter_healthfacility_device_created_and_more"),
        # ("intecomm_screening", "0046_alter_historicalpatientlog_legal_name_and_more"),
        ("intecomm_screening", "0049_healthfacility"),
        ("intecomm_subject", "0063_auto_20230725_2058"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalnextappointment",
            old_name="health_facility",
            new_name="old_health_facility",
        ),
        migrations.RenameField(
            model_name="nextappointment",
            old_name="health_facility",
            new_name="old_health_facility",
        ),
    ]
