# Generated by Django 4.1.2 on 2022-11-25 23:45

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0012_alter_historicalpatientcall_last_attend_clinic_and_more"),
        ("intecomm_group", "0007_remove_historicalpatientfollowupcall_attend_date_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="patientgroup",
            name="dm_patients",
            field=models.ManyToManyField(
                blank=True,
                related_name="dm_patients",
                to="intecomm_screening.patientlog",
                verbose_name="DM-only",
            ),
        ),
        migrations.AddField(
            model_name="patientgroup",
            name="hiv_patients",
            field=models.ManyToManyField(
                blank=True,
                related_name="hiv_patients",
                to="intecomm_screening.patientlog",
                verbose_name="HIV-only",
            ),
        ),
        migrations.AddField(
            model_name="patientgroup",
            name="htn_patients",
            field=models.ManyToManyField(
                blank=True,
                related_name="htn_patients",
                to="intecomm_screening.patientlog",
                verbose_name="HTN-only",
            ),
        ),
        migrations.AddField(
            model_name="patientgroup",
            name="multi_patients",
            field=models.ManyToManyField(
                blank=True,
                related_name="multi_patients",
                to="intecomm_screening.patientlog",
                verbose_name="Multi-morbidity",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatientfollowupcall",
            name="last_attend_clinic",
            field=models.CharField(
                blank=True,
                help_text="This may be helpful when updating health records",
                max_length=25,
                null=True,
                verbose_name="Where did the patient last seek care",
            ),
        ),
        migrations.AlterField(
            model_name="patientfollowupcall",
            name="last_attend_clinic",
            field=models.CharField(
                blank=True,
                help_text="This may be helpful when updating health records",
                max_length=25,
                null=True,
                verbose_name="Where did the patient last seek care",
            ),
        ),
    ]
