# Generated by Django 4.1.7 on 2023-05-09 22:12

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0027_historicalpatientlog_printed_patientlog_printed"),
    ]

    operations = [
        migrations.AlterField(
            model_name="patientlogreportprinthistory",
            name="patient_log_identifier",
            field=models.CharField(max_length=36),
        ),
    ]
