# Generated by Django 4.1.2 on 2022-11-22 19:59

from django.db import migrations, models
import edc_model.models.fields.other_charfield


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_group",
            "0006_remove_historicalpatientgroup_enforce_group_size_min_and_more",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalpatientfollowupcall",
            name="attend_date",
        ),
        migrations.RemoveField(
            model_name="patientfollowupcall",
            name="attend_date",
        ),
        migrations.AddField(
            model_name="historicalpatientfollowupcall",
            name="last_appt_date",
            field=models.DateField(
                blank=True,
                help_text="This may be helpful when updating health records",
                null=True,
                verbose_name="When did the patient last seek care",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientfollowupcall",
            name="last_attend_clinic",
            field=models.CharField(
                blank=True,
                choices=[],
                help_text="This may be helpful when updating health records",
                max_length=25,
                null=True,
                verbose_name="Where did the patient last seek care",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientfollowupcall",
            name="last_attend_clinic_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientfollowupcall",
            name="next_appt_date",
            field=models.DateField(
                blank=True, null=True, verbose_name="When will the patient next attend"
            ),
        ),
        migrations.AddField(
            model_name="patientfollowupcall",
            name="last_appt_date",
            field=models.DateField(
                blank=True,
                help_text="This may be helpful when updating health records",
                null=True,
                verbose_name="When did the patient last seek care",
            ),
        ),
        migrations.AddField(
            model_name="patientfollowupcall",
            name="last_attend_clinic",
            field=models.CharField(
                blank=True,
                choices=[],
                help_text="This may be helpful when updating health records",
                max_length=25,
                null=True,
                verbose_name="Where did the patient last seek care",
            ),
        ),
        migrations.AddField(
            model_name="patientfollowupcall",
            name="last_attend_clinic_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="patientfollowupcall",
            name="next_appt_date",
            field=models.DateField(
                blank=True, null=True, verbose_name="When will the patient next attend"
            ),
        ),
    ]
