# Generated by Django 4.1.7 on 2023-05-10 00:43

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_screening",
            "0028_alter_patientlogreportprinthistory_patient_log_identifier",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalpatientlog",
            name="filing_identifier",
            field=models.CharField(
                blank=True,
                db_index=True,
                help_text="Auto-populated when form is saved. <BR>This is a sequential-like identifier to label this patient's paper file",
                max_length=36,
                verbose_name="Filing number",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatientlog",
            name="patient_log_identifier",
            field=models.CharField(
                blank=True,
                db_index=True,
                help_text="Auto-populated when form is saved. <BR>You may prefer to use the FILING NUMBER. <BR>This identifier is replaced by the 'screening identifier' if the patient screens for the INTECOMM trial",
                max_length=36,
                verbose_name="Patient Log Reference",
            ),
        ),
        migrations.AlterField(
            model_name="patientlog",
            name="filing_identifier",
            field=models.CharField(
                blank=True,
                help_text="Auto-populated when form is saved. <BR>This is a sequential-like identifier to label this patient's paper file",
                max_length=36,
                unique=True,
                verbose_name="Filing number",
            ),
        ),
        migrations.AlterField(
            model_name="patientlog",
            name="patient_log_identifier",
            field=models.CharField(
                blank=True,
                help_text="Auto-populated when form is saved. <BR>You may prefer to use the FILING NUMBER. <BR>This identifier is replaced by the 'screening identifier' if the patient screens for the INTECOMM trial",
                max_length=36,
                unique=True,
                verbose_name="Patient Log Reference",
            ),
        ),
    ]
