# Generated by Django 4.1.2 on 2022-11-21 22:34

from django.db import migrations
import django_crypto_fields.fields.encrypted_char_field
import edc_model.validators.phone


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0004_rename_name_historicalpatientlog_legal_name_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalpatientcall",
            name="alt_contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[edc_model.validators.phone.phone_number],
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientcall",
            name="contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                validators=[edc_model.validators.phone.phone_number],
            ),
        ),
        migrations.AddField(
            model_name="patientcall",
            name="alt_contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[edc_model.validators.phone.phone_number],
            ),
        ),
        migrations.AddField(
            model_name="patientcall",
            name="contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                validators=[edc_model.validators.phone.phone_number],
            ),
        ),
    ]
