# Generated by Django 4.2.3 on 2023-07-25 17:34

import uuid

import _socket
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_crypto_fields.fields.encrypted_text_field
import django_revision.revision_field
import edc_crf.model_mixins.crf_status_model_mixin
import edc_model.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_next_appointment", "0001_initial"),
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("intecomm_subject", "0059_historicalnextappointment_info_source_old_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalnextappointment",
            name="info_source",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                max_length=15,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_next_appointment.infosources",
                verbose_name="What is the source of this appointment date",
            ),
        ),
        migrations.AddField(
            model_name="nextappointment",
            name="info_source",
            field=models.ForeignKey(
                max_length=15,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_next_appointment.infosources",
                verbose_name="What is the source of this appointment date",
            ),
        ),
    ]
