# Generated by Django 4.2.1 on 2023-07-02 12:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0039_alter_historicalpatientlog_options_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="patient_log_identifier",
            field=models.CharField(
                max_length=50, null=True, verbose_name="Patient log identifier"
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="patient_log_identifier",
            field=models.CharField(
                max_length=50, null=True, verbose_name="Patient log identifier"
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="patient_log",
            field=models.OneToOneField(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_screening.patientlog",
            ),
        ),
    ]
