# Generated by Django 4.1.2 on 2022-12-02 23:22

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0002_remove_historicaldminitialreview_managed_by_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="coworkers",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="Do any of your COWORKERS know about your participation in the study?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="friends",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="Do any of your FRIENDS know about your participation in the study?",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="coworkers",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="Do any of your COWORKERS know about your participation in the study?",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="friends",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="Do any of your FRIENDS know about your participation in the study?",
            ),
        ),
    ]
