# Generated by Django 4.2.7 on 2023-12-05 20:40

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_prn", "0014_endofstudy_intecomm_pr_action__f3bf58_idx_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="protocolincident",
            index=models.Index(
                fields=["subject_identifier", "action_identifier", "site"],
                name="intecomm_pr_subject_54092b_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="protocolincident",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_pr_subject_1a96f8_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="protocolincident",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_004622_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="protocolincident",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_90fc4f_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjecttransfer",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__7a579a_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjecttransfer",
            index=models.Index(
                fields=["subject_identifier", "action_identifier", "report_datetime", "site"],
                name="intecomm_pr_subject_cef1b4_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjecttransfer",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_e233b6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjecttransfer",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_7d84b5_idx"
            ),
        ),
    ]
