# Generated by Django 4.2.6 on 2023-11-20 11:05

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0124_auto_20231115_0133"),
    ]

    operations = [
        migrations.AddField(
            model_name="healtheconomicsproperty",
            name="calculated_land_surface_area",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="m2 (system calculated)",
                max_digits=15,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(999999999.99),
                ],
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicsproperty",
            name="calculated_land_surface_area",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="m2 (system calculated)",
                max_digits=15,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(999999999.99),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_surface_area",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=15,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0.1),
                    django.core.validators.MaxValueValidator(999999999.9),
                ],
                verbose_name="Surface area",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_surface_area_units",
            field=models.CharField(
                choices=[
                    ("hectares", "hectares"),
                    ("acres", "acres"),
                    ("decimals", "decimals (1 decimal = hundredth of an acre)"),
                    ("sq_feet", "sq. feet (length * width)"),
                    ("sq_meters", "sq. meters (length * width)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                null=True,
                verbose_name="Surface area (units)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="land_surface_area",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=15,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0.1),
                    django.core.validators.MaxValueValidator(999999999.9),
                ],
                verbose_name="Surface area",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="land_surface_area_units",
            field=models.CharField(
                choices=[
                    ("hectares", "hectares"),
                    ("acres", "acres"),
                    ("decimals", "decimals (1 decimal = hundredth of an acre)"),
                    ("sq_feet", "sq. feet (length * width)"),
                    ("sq_meters", "sq. meters (length * width)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                null=True,
                verbose_name="Surface area (units)",
            ),
        ),
    ]
