# Generated by Django 4.2.7 on 2023-12-05 20:47

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0134_clinicalreviewbaseline_intecomm_su_subject_67b2fa_idx_and_more",
        ),
    ]

    operations = [
        migrations.AddIndex(
            model_name="hivinitialreview",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_a055c4_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivinitialreview",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_21d652_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivinitialreview",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_5813f4_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivmedicationadherence",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_87f6eb_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivmedicationadherence",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_3533ce_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivmedicationadherence",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_a6d4ee_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivreview",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_39226a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivreview",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_33b07e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivreview",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_92f8f9_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htninitialreview",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_411d3a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htninitialreview",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_4d9851_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htninitialreview",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_13e14c_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htnmedicationadherence",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_3317e5_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htnmedicationadherence",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_3a0fea_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htnmedicationadherence",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_50537a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htnreview",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_d895a5_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htnreview",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_c47319_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htnreview",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_af0253_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="icecapa",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_f8d820_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="icecapa",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_9cbbd9_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="icecapa",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_3cffa8_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="locationupdate",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_e27dc5_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="locationupdate",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_8a3358_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="locationupdate",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_593cf3_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="malariatest",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_5275b6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="malariatest",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_551e45_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="malariatest",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_5a20bc_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="medications",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_8737ca_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="medications",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_d955ea_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="medications",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_514814_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="nextappointment",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_226937_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="nextappointment",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_382522_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="nextappointment",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_b2a703_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="otherbaselinedata",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_daeaa1_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="otherbaselinedata",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_09f4e6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="otherbaselinedata",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_16e1f9_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="socialharms",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_614268_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_su_subject_e4994e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["subject_visit", "site", "panel"],
                name="intecomm_su_subject_c4f624_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["subject_visit", "panel"], name="intecomm_su_subject_01e2c9_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_7e0b1f_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_595b8a_idx"
            ),
        ),
    ]
