# Generated by Django 4.1.2 on 2023-01-27 01:50

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0010_remove_historicalvitals_weight_is_estmated_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="clinicalreviewbaseline",
            name="complications",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreviewbaseline",
            name="complications",
        ),
        migrations.AlterField(
            model_name="historicalvitals",
            name="severe_htn",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="No",
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/110mmHg",
                max_length=15,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="vitals",
            name="severe_htn",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="No",
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/110mmHg",
                max_length=15,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
    ]
